﻿using UnityEngine;
using System.Collections;
using System.Linq;
using Priority_Queue;

public class Card : MonoBehaviour 
{	
	public enum Suit
	{
		spade,
		heart,
		diomond,
		club,
		Null //null for joker
	}

	public enum Rank
	{
		ace = 1,
		two,
		three,
		four,
		five,
		six,
		seven,
		eight,
		nine,
		ten,
		jack,
		queen,
		king,
		joker,
		joker1
	}

	public enum RankHigh
	{
		two = 2,
		three,
		four,
		five,
		six,
		seven,
		eight,
		nine,
		ten,
		jack,
		queen,
		king,
		ace,
		joker,
		joker1
	}

	Suit suit;
	Rank rank;
	RankHigh rankHigh;

	public Suit cardSuit{ get { return suit; } set { suit = value; } }
	public Rank cardRank{get{return rank;} set{ rank = value;}}
	public RankHigh cardRankHigh{get{return rankHigh;} set{rankHigh = value;}}

	public Card(Suit s , Rank r)
	{
		suit = s;
		rank = r;
	}

	public Card(Rank r)
	{
		rank = r;
	}
	
	public Transform TargetTransform 
	{ 
		get 
		{ 
			if (_targetTransform == null)
			{
				GameObject gameObject = new GameObject(this.name + "Target");
				_targetTransform = gameObject.GetComponent<Transform>();
				_targetTransform.position = transform.position;
				_targetTransform.forward = transform.forward;				
			}
			return _targetTransform; 
		}
	}

	private Transform _targetTransform;	
    
	public CardSlot ParentCardSlot { get; set; }

	[SerializeField]
	public int FaceValue { get; set; }

	[SerializeField]
	public int ScoreValue{ get; set;}

	[SerializeField]
	public Sprite[] _cardTexture;
    
	private float _positionDamp = .2f;

	private float _rotationDamp = .2f;   

	[HideInInspector]
	public bool isSelected;
	private bool isZooming;
	private Vector3 offsetScale;

	private Vector3 _dist;
//	private float _posX;
//	private float _posY;

	private Player player;

	[SerializeField]
	private GameObject TrumpcardSprite;
	private bool isTrumpDisplay = true;

	[HideInInspector]
	public bool isCardDrag = false;

	private void Awake()
	{
		isSelected = false;
		isZooming = false;
	}

	private void Update()
	{
		if (!isSelected && !isCardDrag && !Dealer._manage._player[0].GetComponent<Player>().isDrawHand)
			SmoothToTargetPositionRotation ();
		
		if(this.isTrumpDisplay)
			DisplayTrumpStar ();
	}

	private void OnMouseDown()
	{
		if (!isSelected) 
		{
			_dist = Camera.main.WorldToScreenPoint (transform.position);
//			_posX = Input.mousePosition.x - _dist.x;
//			_posY = Input.mousePosition.y - _dist.y;
		}
//		Debug.Log (this.transform.parent.GetComponent<Player> ());
//		if (PlayareaManager.manage.CurrentplayerTurn == 0) 
//		{
			if (this.transform.parent.gameObject.name == "TrumpCard") 
			{
				return;
			} 
			else if (this.transform.parent.gameObject.name == "StackCardSlot" && Dealer._manage._player [0].cards.Count <= 14) 
			{
			if (PlayareaManager.manage.CurrentTurn == 0) //Dealer._manage.Player[PlayareaManager.manage.CurrentplayerTurn].GetComponent<Player>().isMyTurn()
				{
//					Debug.Log ("Else If Call - 1");
					//Check StackPile Empty or Not
					if (Dealer._manage._stackCardSlot.CardList.Count > 0) 
					{
						Dealer._manage._player [0].GetComponent<Player> ().TakeCardFromStackPile (this);
						Dealer._manage._stackCardSlot.RemoveCard (this);
						Dealer._manage._stackCardSlot.CardList.Remove (this);
					}
					else
					{
						if(Dealer._manage._stackCardSlot.CardList.Count == 0)
						{
//							Debug.Log ("Stock Pile is Empty Fill it...!!!");
							//Take Top card
							Card topCard = Dealer._manage._discardspile.TopCard ();

							//Remove Top Card
							Dealer._manage._discardspile.RemoveCard (topCard);

//							Debug.Log (Dealer._manage._discardspile.CardList.Count);

							//Move Discard Pile to Stock Pile
							for(int i = 0; i < Dealer._manage._discardspile.CardList.Count; i++)
							{
								Card card = Dealer._manage._discardspile.CardList[0];
								Dealer._manage._stackCardSlot.AddCard (card);
								card.gameObject.SetActive(false);
								Dealer._manage._discardspile.RemoveCard (card);
							}

							//Now Add Top Card To DisscardPile
							Dealer._manage._discardspile.CardList.Add (topCard);
						}
					}
				}
			} 
			else if (this.transform.parent.gameObject.name == "DiscardPile" && Dealer._manage._player [0].cards.Count <= 14) 
			{
				if (PlayareaManager.manage.CurrentTurn == 0 && !Dealer._manage._player [0].GetComponent<Player>().isTakeFromStockPile) 
				{
//					Debug.Log ("Else If Call - 2");
					//check Discarded card
					for (int i = 0; i < Dealer._manage._player [0].GetComponent<Player> ().discardedCard.Count; i++) 
					{
						if (this.cardSuit == Dealer._manage._player [0].GetComponent<Player> ().discardedCard [i].cardSuit && this.cardRank == Dealer._manage._player [0].GetComponent<Player> ().discardedCard [i].cardRank) 
						{
//							Debug.Log ("Discarded Card Can Not Taken Return");
							return;
						}
					}

					//Check if card taken 3 times from takeFromdiscardPile 
					if (Dealer._manage._player [0].GetComponent<Player> ().takeFromDiscardPile.Count < 3) 
					{
						Dealer._manage._player [0].GetComponent<Player> ().TakeCard (this);

						//Display Taken card Pic In above card
//						Dealer._manage._player [0].GetComponent<Player> ()._discardPileSprite [Dealer._manage._player [0].GetComponent<Player> ().takeFromDiscardPile.Count].sprite = this._cardTexture [this.FaceValue - 1];
//						Dealer._manage._player [0].GetComponent<Player> ().takeFromDiscardPile.Add (this);
					}
					else
						return;
				}
			}
			else if (!this.transform.parent.GetComponent<Player> ().isAiPlayer) 
			{
//				Debug.Log ("Else If Call - 3");
				player = Dealer._manage._player [0].GetComponent<Player> ();//Dealer._manage._player [0].GetComponent<Player> ();

				if (player) //&& player.isMyTurn 
				{
					Select (!isSelected);
				}
			}
//		}
	}

//	private void OnMouseEnter()
//	{
//		if (!isZooming) {
//			ZoomCard (!isZooming);
//		}
//	}
//	private void OnMouseExit()
//	{
//		if (isZooming) {
//			ZoomCard (!isZooming);
//		}
//	}

	private void OnMouseDrag()
	{
		if(!isSelected)
		{
			Vector2 mousePos = new Vector2 (Input.mousePosition.x, Input.mousePosition.y);
			Vector2 objectPos = Camera.main.ScreenToWorldPoint (mousePos);
			this.transform.position = objectPos;
		}
	}


	private void ChangeCardSpriteOrder(int order)
	{
		SpriteRenderer CardRender = GetComponent<SpriteRenderer> ();
		CardRender.sortingOrder = order;
	}

	public void DisplayTrumpStar()
	{
		//Search Trump Card and Display Star
		if (PlayareaManager.manage.state == PlayareaManager.GameState.start) 
		{
			if (this.cardRank == Dealer._manage.GetTrumpCard ().cardRank) 
			{
				TrumpcardSprite.GetComponent<SpriteRenderer>().enabled = true;
				TrumpcardSprite.GetComponent<SpriteRenderer> ().sortingOrder = TrumpcardSprite.transform.parent.GetComponent<SpriteRenderer> ().sortingOrder;
				isTrumpDisplay = false;
			}
		}
	}
		
	public void SetDamp(float newPositionDamp, float newRotationDamp)
	{
		_positionDamp = newPositionDamp;
		_rotationDamp = newRotationDamp;
	}
	
	public void SmoothToTargetPositionRotation()
	{
		if (TargetTransform.position != transform.position || TargetTransform.eulerAngles != transform.eulerAngles || !isSelected)
		{
			SmoothToPointAndDirection(TargetTransform.position, _positionDamp, TargetTransform.rotation, _rotationDamp);	
		}    	
	}	
    
	private void SmoothToPointAndDirection(Vector3 point, float moveSmooth, Quaternion rotation, float rotSmooth)
	{
		transform.position = Vector3.SmoothDamp(transform.position, point, ref _smoothVelocity, moveSmooth);	
		Quaternion newRotation;
		newRotation.x = Mathf.SmoothDamp(transform.rotation.x, rotation.x, ref _smoothRotationVelocity.x, rotSmooth); 
		newRotation.y = Mathf.SmoothDamp(transform.rotation.y, rotation.y, ref _smoothRotationVelocity.y, rotSmooth); 
		newRotation.z = Mathf.SmoothDamp(transform.rotation.z, rotation.z, ref _smoothRotationVelocity.z, rotSmooth); 		  
		newRotation.w = Mathf.SmoothDamp(transform.rotation.w, rotation.w, ref _smoothRotationVelocity.w, rotSmooth); 		  
		transform.rotation = newRotation;	
		TestVisibility();					     
	}

	private Vector3 _smoothVelocity;
	private Vector4 _smoothRotationVelocity;	
    
	private void TestVisibility()
	{
		float angle = Vector3.Angle(Camera.main.transform.forward, transform.forward);

		if (angle < 91)
		{
			FrontBecameVisible();
		}
		else
		{
			FrontBecameHidden();
		}
	}
		
	private void FrontBecameVisible()
	{
		GetComponent<SpriteRenderer> ().sprite = _cardTexture [FaceValue - 1];
		DisplayTrumpStar ();
	}
	
	private void FrontBecameHidden()
	{
		GetComponent<SpriteRenderer>().sprite = null;
		TrumpcardSprite.GetComponent<SpriteRenderer>().enabled = false;
		TrumpcardSprite.GetComponent<SpriteRenderer> ().sortingOrder = TrumpcardSprite.transform.parent.GetComponent<SpriteRenderer> ().sortingOrder;
	}

	public void ChangeParent (Transform parent) {
		transform.parent = parent;
		transform.localPosition = Vector3.zero;
		transform.localScale = Vector3.one;
	}

	public void Select (bool nextIsSelected) 
	{
//		Debug.Log ("Call");
		Vector3 selectedOffset = new Vector3(0.0f, 0.25f, 0.0f);
		if (isSelected != nextIsSelected) 
		{
			Player player = Dealer._manage._player [PlayareaManager.manage.CurrentTurn].GetComponent<Player> ();

			if (nextIsSelected) 
			{
				// selected
				transform.localPosition += selectedOffset;
//				Debug.Log (player.GetComponent<Player> ().takeFromDiscardPile.Count);

				if (PlayareaManager.manage.CurrentTurn == 0)
					{
						
						if (player.GetComponent<Player> ().takeFromDiscardPile.Count == 0) 
						{
							player.selectedCards.Add (this);
						}
//						else if(player.GetComponent<Player> ().takeFromDiscardPile [player.GetComponent<Player> ().takeFromDiscardPile.Count - 1].FaceValue == this.FaceValue)
//						{
//							Debug.Log("Selected card same as card taken from discardPile");
//							return;
//						}
						else
							player.selectedCards.Add (this);
					}
			}
			else
			{
				// unselected
				transform.localPosition -= selectedOffset;
				if(PlayareaManager.manage.CurrentTurn == 0)
					player.selectedCards.Remove(this);
			}
			isSelected = nextIsSelected;
		}
	}

	private void ZoomCard(bool nextZoomed)
	{
		offsetScale = new Vector3 (0.1f, 0.1f, 0.0f);
		if(isZooming != nextZoomed)
		{
			if(nextZoomed)
			{
				transform.localScale += offsetScale;	
			}
			else
			{
				transform.localScale -= offsetScale;
			}
			isZooming = nextZoomed;
		}
	}
}
