﻿using UnityEngine;
using System.Collections;
using System.IO;
using System.Linq;
public class Dealer : MonoBehaviour 
{
	public DealerUI DealerUIInstance { get; set; }

	[SerializeField]
	public Player[] _player;

	[SerializeField]
	private Hand[] _hand;
    
	[SerializeField]
	public CardDeck _cardDeck;		

	[SerializeField]
	public CardSlot _stackCardSlot;	

	[SerializeField]
	public CardSlot _discardspile;

	[SerializeField]
	public CardSlot _trumpCard;																																							

	private const float CardStackDelay = .01f;
	
	/// <summary>
	/// Counter which keeps track current dealing movements in progress.
	/// </summary>
	public int DealInProgress { get; set;}

	public static Dealer _manage;

	private void Awake()
	{
		_manage = this;
	}

	public void Init()
	{
		_cardDeck.InstanatiateDeck();
		StartCoroutine(StackCardRangeOnSlot(0, _cardDeck.CardList.Count, _stackCardSlot));
		Invoke ("ServeCard", 3);
	}

//	private void Update()
//	{
//		if(PlayareaManager.manage.state == PlayareaManager.GameState.start)
//			CheckAndDeclairWinner ();
//	}

	private void ServeCard()
	{
		StartCoroutine ("ServeCards");
	}

	public void PlayerTurn(int currentTurn)
	{
		for (int i = 0; i < _player.Count(); i++) 
		{
			_player [i].GetComponent<Player> ().isMyTurn = false;				
		}
		_player [currentTurn].GetComponent<Player> ().isMyTurn = true;
	
		if(currentTurn != 0)
			StartCoroutine (CallAiPlayer(currentTurn));
	}

	public void CheckAndDeclairWinner()
	{
//		int i;
//		int NumberOfPlayer = _player.Count ();
//		for (i = 0; i < NumberOfPlayer; i++)
//		{
////			Debug.Log (i);
//			if(_player[i].GetComponent<Player>().DeadWoodCounts <= 10)//_hand[i].ScoreHand())
//			{
////				Debug.Log (i +" No. "+_player [i] + " is Winner" + "DeadWood is :" + _player[i].GetComponent<Player>().DeadWoodCounts);
//				PlayareaManager.manage.EndDiscardCard.SetActive (true);
//			//	PlayareaManager.manage.state = PlayareaManager.GameState.gameOver;
//				MoneyCardCalculation ();
//				BetAmountCalculation (i);
//				PlayareaManager.manage.DeclareAndDisplayWinner (i);
//			}
//		}
	}

	private void BetAmountCalculation(int winnerPlayer)
	{
		int NumberOfPlayer = Dealer._manage._player.Length;
		for(int i = 0; i < NumberOfPlayer; i++)
		{
			if(i == winnerPlayer)
			{
				Dealer._manage._player [i].BetAmount = (PlayareaManager.FixBetPrice * (NumberOfPlayer - 1));
			}
			else
				Dealer._manage._player [i].BetAmount -= PlayareaManager.FixBetPrice;
		}
	}

	private void MoneyCardCalculation()
	{
		int i;
		int NumberOfPlayer = Dealer._manage._player.Length;

		for(i = 0; i < NumberOfPlayer; i++)
		{
			for(int j = 0; j < Dealer._manage._player[i].GetComponent<Player>().cards.Count; j++)
			{
				if(Dealer._manage._player[i].cards[j] == Dealer._manage._trumpCard || Dealer._manage._player[i].cards[j] == Dealer._manage._discardspile.TopCard() || Dealer._manage._player[i].cards[j].cardSuit == Card.Suit.Null)
				{
					Debug.Log (Dealer._manage._player [i].cards [j]);
					Dealer._manage._player [i].moneyCardCount++;
				}
			}
			Debug.Log ("money card of player" + i +" :" + Dealer._manage._player [i].moneyCardCount);
		}

		//find Player who have Max Money Card in hand
		int maxMoneyCard = 0;
		for(i = 0; i < NumberOfPlayer; i++)
		{
			//Check Which Player have a maximum Money card
			if(Dealer._manage._player[i].moneyCardCount > maxMoneyCard)
			{
				maxMoneyCard = Dealer._manage._player [i].moneyCardCount;
			}
		}
			
		for(i = 0; i < NumberOfPlayer; i++)
		{
			if (Dealer._manage._player [i].moneyCardCount != maxMoneyCard) 
			{
				Dealer._manage._player [i].moneyCardCount = Dealer._manage._player [i].moneyCardCount - maxMoneyCard;
			}
			Debug.Log("Player:-"+ i + "-" + Dealer._manage._player [i].moneyCardCount);
		}
	}
    
	private void MoveCardSlotToCardSlot(CardSlot sourceCardSlot, CardSlot targetCardSlot) 
	{
		Card card;
		while ((card = sourceCardSlot.TopCard()) != null)
		{
			targetCardSlot.AddCard(card);
		}
	}

	public void MoveCardToCard(CardSlot sourceCardSlot, CardSlot targetCardSlot) 
	{
		Card card;
		if ((card = sourceCardSlot.TopCard()) != null)
		{
			targetCardSlot.AddCard(card);
		}
	}
	
	private IEnumerator StackCardRangeOnSlot(int start, int end, CardSlot cardSlot) 
	{
		DealInProgress++;
		for (int i = start; i < end; ++i)
		{
			cardSlot.AddCard(_cardDeck.CardList[i]);
			yield return new WaitForSeconds(CardStackDelay);
		}
//		Debug.Log (cardSlot.CardCount ());
		DealInProgress--;
	}

	private IEnumerator ServeCards()
	{
		for(int i = 0; i < _player.Length; i++)
		{
			for(int j = 0; j < 13; j++)
			{
				//take Top card From Deck and add into Player's Hands
				Card card = _stackCardSlot.TopCard ();
				//_stackCardSlot.RemoveCard(card);
				_player [i].HandCard [j].AddCard (card);
				_hand[i].cards.Add(_player [i].HandCard [j].TopCard());
				_player [i].cards.Add (_player [i].HandCard [j].TopCard());

				//Set Player handCard In Order and Set that as isAiPlayer false to indicate that this is player
				if (i == 0) 
				{
					_player [i].cards [j].GetComponent<SpriteRenderer> ().sortingOrder = j;
					_player [i].isAiPlayer = false;
				}
				else
					_player [i].isAiPlayer = true;
				
				yield return new WaitForSeconds(CardStackDelay * 5);

				//change all Player Card Parent and Set Scale Of Hand card
				_player[i].cards[j].ChangeParent (_player [i].transform);
				_player[i].cards[j].transform.localScale = new Vector3(0.7f,0.7f,0.7f);//0.55
			}
			_player [i].Sort ();
		}
			

		//check Stack top card is a joker card OR Not
		Recheck:
//		Debug.Log (_stackCardSlot.TopCard ());
		if(_stackCardSlot.TopCard().cardRank == Card.Rank.joker || _stackCardSlot.TopCard().cardRank == Card.Rank.joker1)
		{
			int j = Random.Range (0, _stackCardSlot.CardList.Count);
			Card card = _stackCardSlot.CardList [j];
//			Debug.Log (card.cardRank + ":-" + card.cardSuit);
			_stackCardSlot.CardList [j] = _stackCardSlot.CardList [0];
			_stackCardSlot.CardList [0] = card;

//			Debug.Log ("Top card is joker SuffleDeck");
			goto Recheck;
		}	


		//Select  Trump card And add in TrupcardSlot and Remove from StockcardSlot
		_stackCardSlot.TopCard ().transform.parent = _trumpCard.transform;
		_trumpCard.AddCard (_stackCardSlot.TopCard ());
		_trumpCard.TopCard ().GetComponent<SpriteRenderer> ().sortingOrder = 0;


		yield return new WaitForSeconds (CardStackDelay);

		//Add Card In DiscardPileSloat and Remove card fromStackCardSlot
		_stackCardSlot.TopCard ().transform.parent = _discardspile.transform;
		_discardspile.AddCard (_stackCardSlot.TopCard ());

		yield return new WaitForSeconds (CardStackDelay);

		//Now Star Game
		PlayareaManager.manage.state = PlayareaManager.GameState.start;

		//Sorting Hand
		for(int i = 0; i < _player.Length; i++)
		{
			Dealer._manage._player [i].GetComponent<Player> ().Sort ();
		}
	}

	//return a Trupcard
	public Card GetTrumpCard()
	{
		return _trumpCard.CardList[0];
	}


	IEnumerator CallAiPlayer(int CurrentPlayerTurn)
	{
		yield return  new WaitForSeconds (1);
		Dealer._manage._player [CurrentPlayerTurn].GetComponent<Player>().AIPlayer ();
	}
}
