﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;
using Facebook.Unity;
public class PlayareaManager : MonoBehaviour 
{	
	//Enum for different Game State
	public enum GameState
	{
		start,
		pause,
		servecard,
		BetAmount,
		gameOver
	}

	public GameState state;
	public GameObject PauseMenu;
	public GameObject quitAlert;
	public GameObject winAlert;
	public GameObject EndDiscardCard;
	public Button PauseBt;
	public GameObject displayRules;
	public Deck<PlayingCard> deck;
	public Text StockPileCardCount;
	public RoomDetails[] currentRoom;
	public Sprite[] cardtexture;

	[System.Serializable]
	public class RoomDetails
	{
		public string roomname;
		public int betAmount;
	}

	public PlayerDetails[] PlayerInfo;

	[System.Serializable]
	public class PlayerDetails
	{
		public string Name = "Player";
		public Text PlayerName;
		public Image playerimg;
		public Image Timerimg;
		public Text PlayerAmount;
		public GameObject betAnimText;
	}

	public PlayerData playerDatas;

	[System.Serializable]
	public class PlayerData
	{
		public string[] Name;
		public Sprite[] ProfilePic;
		public int[] CoinAmount;
	}

	public WinnerDetails[] winerPlayerInfo;

	[System.Serializable]
	public class WinnerDetails
	{
		public string Playername;
		public Image playerpic;
		public Image[] cards;
		public Text Result;
		public Text BetAmount;
		public Text MoneyCard;
		public Text Total;
	}
		
	public float Timer = 0;
	[SerializeField]
	private float MaxTimer = 60;
	//[SerializeField]
	public int CurrentplayerTurn = 0; 

	public const int FixBetPrice = 50;
	public int CurrentTurn = 0;
	public static PlayareaManager manage;
	void Awake()
	{
		manage = this;
		state = GameState.servecard;
	}

	// Use this for initialization
	void Start () 
	{
		Application.runInBackground = true;

		PauseMenu.SetActive (false);
		quitAlert.SetActive (false);
		displayRules.SetActive (false);
		IntializePlayers();
		Dealer._manage.Init ();
	}

	private void IntializePlayers()
	{
		PlayerInfo [0].PlayerName.text = GameData.LoadPlayerName ();
		PlayerInfo [0].PlayerAmount.text = ConvertCoin(GameData.LoadCoin ());

		if (FB.IsLoggedIn) 
		{
			PlayerInfo [0].playerimg.sprite = playerDatas.ProfilePic [GameData.LoadProfile ()];
		}
		else 
		{
			PlayerInfo [0].playerimg.sprite = playerDatas.ProfilePic [GameData.LoadProfile()];
			//			FBlogin ();
		}

		int index = playerDatas.ProfilePic.Length;

		for(int i = 1; i < Dealer._manage._player.Length; i++)
		{
			PlayerPrefs.SetInt (i + "AiPlayerCount", Random.Range (0, index));
			PlayerInfo [i].PlayerName.text = playerDatas.Name [PlayerPrefs.GetInt(i+"AiPlayerCount")];
			//Debug.Log (Random.Range (currentRoom [GameData.LoadRoom ()].betAmount, currentRoom [GameData.LoadRoom ()].betAmount + Random.Range (0, currentRoom [GameData.LoadRoom ()].betAmount)));

			PlayerPrefs.SetInt (i + "AiPlayer", Random.Range (currentRoom [GameData.LoadRoom ()].betAmount / 2, currentRoom [GameData.LoadRoom ()].betAmount));
			
			PlayerInfo [i].PlayerAmount.text = ConvertCoin (PlayerPrefs.GetInt(i +"AiPlayer"));
			PlayerInfo [i].playerimg.sprite = playerDatas.ProfilePic [PlayerPrefs.GetInt(i+"AiPlayerCount")];
		}
		Dealer._manage.PlayerTurn (CurrentplayerTurn);
	}

	public void BetAmount()
	{
		for(int i = 0; i < Dealer._manage._player.Length; i++)
		{
			if(i == 0)
			{
				PlayerInfo [0].PlayerAmount.text = ConvertCoin (GameData.LoadCoin () - FixBetPrice);
				GameData.SaveCoin (GameData.LoadCoin () - FixBetPrice);
				//PlayerInfo [0].betAnimText.SetActive (true);
			}
			else
			{
				PlayerInfo [i].PlayerAmount.text = ConvertCoin (PlayerPrefs.GetInt(i +"AiPlayer") - FixBetPrice);
				//PlayerInfo [i].betAnimText.SetActive (true);
			}
		}
	}

	// Update is called once per frame
	void Update () 
	{
		if(state == GameState.start) //!Dealer._manage._player[0].isTakeFromStockPile
		{
			Timer += Time.deltaTime * 2;
			if (Timer >= MaxTimer) 
			{
				Timer = 0;
				PlayerInfo [CurrentplayerTurn].Timerimg.fillAmount = 0;

				//check Local Player turn is over or not
				if (CurrentplayerTurn == 0)
				{
					if (Dealer._manage._player [0].cards.Count == 14 && Dealer._manage._player[0].selectedCards.Count >= 0)
						Dealer._manage._player [0].GetComponent<Player> ().TimeUpsDrop	 ();

					Dealer._manage._player [CurrentplayerTurn].GetComponent<Player> ().isDropMyTurn = false;
				}
				else
				{
					Dealer._manage._player [CurrentplayerTurn].GetComponent<Player> ().isDropMyTurn = false;
				}

				CurrentplayerTurn ++;


				if (CurrentplayerTurn > Dealer._manage._player.Length - 1) 
				{
					CurrentTurn = 0;

					//Check StackPile Empty or not If Is it then Fill it
					if(Dealer._manage._stackCardSlot.CardList.Count == 0)
					{
						Debug.Log ("Stock Pile is Empty Fill it...!!!");
						Dealer._manage._player [0].GetComponent<Player> ().RefillStackPile ();
					}
				}
				else
					CurrentTurn = CurrentplayerTurn;

				if (CurrentplayerTurn == Dealer._manage._player.Length)
					CurrentplayerTurn = 0;

//				Debug.Log ("CurrentTurn: " + CurrentTurn);
//				Debug.Log ("DeadWood is :" + Dealer._manage._player [CurrentTurn].DeadWoodCounts);

				Dealer._manage.PlayerTurn (CurrentplayerTurn);
				Dealer._manage._player [CurrentplayerTurn].GetComponent<Player> ().Sort ();
				Dealer._manage.CheckAndDeclairWinner ();
			}

			PlayerInfo [CurrentTurn].Timerimg.fillAmount = Timer / MaxTimer;
		}
		//stock pile cards count
		StockPileCardCount.text = "" + Dealer._manage._stackCardSlot.CardList.Count;//.CardCount ();
	}

	public void DeclareAndDisplayWinner(int winnerPlayer)
	{
		if(state == GameState.start)
		{
			for(int i = 0; i < Dealer._manage._player.Length; i++)
			{
				int betCount = Dealer._manage._player [i].BetAmount;
				int moneyCard = Dealer._manage._player [i].moneyCardCount  * 20;

				Debug.Log (betCount);
				Debug.Log (moneyCard);

				if (i == 0) 
				{
					if(i == winnerPlayer)
					{
						winerPlayerInfo [i].Result.text = "Win";
						winerPlayerInfo [i].Result.color = Color.yellow;
					}
					else
					{
						winerPlayerInfo [i].Result.text = "Loss";
						winerPlayerInfo [i].Result.color = Color.yellow;
					}
//					winerPlayerInfo[i].playerpic.sprite = ;
					winerPlayerInfo [i].BetAmount.text = ""+ betCount;
					winerPlayerInfo [i].BetAmount.color = Color.yellow;
					winerPlayerInfo [i].MoneyCard.text = ""+ moneyCard;
					winerPlayerInfo [i].MoneyCard.color = Color.yellow;
					winerPlayerInfo [i].Total.text = "" + (GameData.LoadCoin () + betCount + moneyCard);
					winerPlayerInfo [i].Total.color = Color.yellow;

				}
				else
				{
					winerPlayerInfo[i].playerpic.sprite = playerDatas.ProfilePic [PlayerPrefs.GetInt(i+"AiPlayerCount")];
					winerPlayerInfo [i].BetAmount.text = ""+ betCount;
					winerPlayerInfo [i].MoneyCard.text = ""+ moneyCard;
					winerPlayerInfo [i].Total.text = "" + (PlayerPrefs.GetInt (i + "AiPlayer") + betCount + moneyCard);

					if(i == winnerPlayer)
					{
						winerPlayerInfo [i].Result.text = "Win";
					}
					else
					{
						winerPlayerInfo [i].Result.text = "Loss";
					}
				}

				for(int j = 0; j < Dealer._manage._player[i].GetComponent<Player> ().cards.Count; j++)
				{
					winerPlayerInfo [i].cards [j].sprite = cardtexture [Dealer._manage._player [i].GetComponent<Player> ().cards [j].FaceValue - 1];
					winerPlayerInfo [i].cards [j].enabled = true;
				}
			}

			winAlert.SetActive (true);
			state = GameState.gameOver;
		}
	}

	public void Pauseclick()
	{
		PauseMenu.SetActive (true);
		state = GameState.pause;
		PauseBt.onClick.AddListener (
			delegate {
				ClosePause ();
			});
	}

	private string ConvertCoin(int coin)
	{
//		int coin = coin;

		if (coin > 1000) {
			coin = coin / 1000;
			return coin+"k";
		} 
		else
			return ""+coin;
	}

	public void ClosePause()
	{
		PauseMenu.SetActive (false);
		state = GameState.start;
		PauseBt.onClick.AddListener (
			delegate {
				Pauseclick ();
			});
	}

	public void WinAlertCLose()
	{
		winAlert.SetActive (false);
	}

	public void QuitAlert()
	{
		quitAlert.SetActive (true);
	}

	public void YesQuitClick()
	{
		SceneManager.LoadScene ("Splash");
	}

	public void NoQuitClick()
	{
		quitAlert.SetActive (false);
	}

	public void DisplayRules()
	{
		displayRules.SetActive (true);
	}

	public void CloseDisplayRules()
	{
		displayRules.SetActive (false);
	}
}