﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;
public class SplashManager : MonoBehaviour 
{
	public GameObject modePannel;
	public GameObject lobbyPannel;
	public GameObject inAppPannel;
	public GameObject playerInfopannel;
	public GameObject loadingPannel;
	public GameObject notEnoughCoinPannel;

	public Image playerProfileimg;
	public Sprite[] profileimgtexure;
	public GameObject[] selectedProfile;
	public Image lobbyPannePlayerImg;

	public Image loadingFilBar;
	public Text loadingPercentageTxt;

	public PlayerDetails playerinfo;
	[System.Serializable]
	public class PlayerDetails
	{
		public Text[] playerNametxt;
		public Text[] playerIdtxt;
	}

	public GameObject editPlayerNameButton;

	public Button freeChipsClamBtn;
	public Sprite[] chipsClamImg;

	public Text[] totalCoinText;
	public Text freeChipsText;

	public static SplashManager manage;

	private int coin;


	#region Unity_Calls
	private void OnEnable()
	{
		playerinfo.playerNametxt [1].GetComponent<InputField> ().onEndEdit.AddListener (delegate {
			EditPlayerName ();
		});
	}

	// Use this for initialization
	private void Start () 
	{
		manage = this;
		
		modePannel.SetActive (true);
		lobbyPannel.SetActive (false);
		inAppPannel.SetActive (false);
		playerInfopannel.SetActive (false);
		loadingPannel.SetActive (false);

		//LobbyPannePlayerImg.sprite = profileimgtexure [GameData.LoadProfile()];
		SlecetProfilePic (GameData.LoadProfile ());
		CheckPlayerName ();
	}
	
	// Update is called once per frame
	private void Update () 
	{
		if(coin != GameData.LoadCoin())
		{
			coin = GameData.LoadCoin();
			for (int i = 0; i < totalCoinText.Length; i++) 
			{
				totalCoinText[i].text = "" + coin;
			}
		}

		//Update Free coin text
		FreeChips.ShowTime (freeChipsText);
		// chenge Freechips Claim Image Texture
		if (FreeChips.isFreeChips)
			freeChipsClamBtn.image.sprite = chipsClamImg [0];
		else
			freeChipsClamBtn.image.sprite = chipsClamImg[1];
	}

//	private void OnDestroy()
//	{
//		playerinfo.playerNametxt [1].GetComponent<InputField> ().onEndEdit.RemoveAllListeners ();
//	}
	#endregion

	#region PublicMethods

	/// <summary>
	/// For Free Mode/Offline Playing
	/// </summary>
	public void FreeMode()
	{				
		modePannel.SetActive (false);
		lobbyPannel.SetActive (true);

		if(PlayerPrefs.GetInt("Firsttime") == 0)
		{
			PlayerInformation ();
			PlayerPrefs.SetInt ("Firsttime", 123123123);
		}
		GameData.SaveMode (0);
	}

	/// <summary>
	/// Redirect to lobbyPannel to ModePannel
	/// </summary>
	public void LobbyBackclick()
	{
		modePannel.SetActive (true);
		lobbyPannel.SetActive (false);
	}

	/// <summary>
	/// Open inapppurchase Pannel
	/// </summary>
	public void getchips()
	{
		lobbyPannel.SetActive (false);
		inAppPannel.SetActive (true);
	}

	/// <summary>
	/// Gets the chips to lobby. close in-app purchase Alert.
	/// </summary>
	public void GetChipsToLobby() //close Get chips alert
	{
		inAppPannel.SetActive (false);
		lobbyPannel.SetActive (true);
	}

	/// <summary>
	/// Open Player information pannel.
	/// </summary>
	public void PlayerInformation()
	{
		playerInfopannel.SetActive (true);
	}

	/// <summary>
	/// Closes the player info.
	/// </summary>
	public void ClosePlayerInfo()
	{
		playerInfopannel.SetActive (false);
	}

	/// <summary>
	/// Slecets the profile pic in Player information Alert.
	/// </summary>
	/// <param name="Number">Number.</param>
	public void SlecetProfilePic(int Number)
	{
		playerProfileimg.sprite = profileimgtexure [Number];
		lobbyPannePlayerImg.sprite = profileimgtexure [Number];
		GameData.SaveProfile (Number);
		//PlayerPrefs.SetInt ("PlayerPic",Number);
		for(int i = 0; i < selectedProfile.Length; i++)
		{
			selectedProfile[i].SetActive (false);

			if(i == Number)
				selectedProfile[i].SetActive (true);
		}
	}

	public void selectProfilePic(Sprite profilePic)
	{

		playerProfileimg.sprite = profilePic;
		lobbyPannePlayerImg.sprite = profilePic;
		/*/GameData.SaveProfile (Number);*/
		//PlayerPrefs.SetInt ("PlayerPic",Number);
		for(int i = 0; i < selectedProfile.Length; i++)
		{
			selectedProfile[i].SetActive (false);
		}
	}

	/// <summary>
	/// Edits the name of the player.
	/// </summary>
	public void EditPlayerName()
	{
		playerinfo.playerNametxt [1].GetComponent<InputField> ().enabled = true;
	}

	/// <summary>
	/// When User End Editing name That Time "ONEndEdit" Method is call
	/// </summary>
	public void ONEndEdit()
	{
		playerinfo.playerNametxt [1].GetComponent<InputField> ().enabled = false;
		GameData.SavePlayerName (playerinfo.playerNametxt [1].text);
		CheckPlayerName ();
	}

	/// <summary>
	/// Checks the name of the player and update Name.
	/// </summary>
	public void CheckPlayerName()
	{
		for(int i =0;i< playerinfo.playerNametxt.Length; i++)
		{
			playerinfo.playerNametxt [i].text = GameData.LoadPlayerName ();
		}
	}

	public void CheckPlayerName(string name)
	{
		for(int i =0;i< playerinfo.playerNametxt.Length; i++)
		{
			playerinfo.playerNametxt [i].text = name;
			GameData.SavePlayerName(name);
		}
	}

	/// <summary>
	/// Selects the room of rummy.
	/// </summary>
	/// <param name="amount">Amount.</param>
	public void SelectRoom(int amount)
	{
		int coin = GameData.LoadCoin ();
		if (amount <= coin) 
		{
			GameData.SaveCoin ((coin - amount));
			lobbyPannel.SetActive (false);
			loadingPannel.SetActive (true);
			StartCoroutine (StartLoading ());

			switch (amount) 
			{
			case 10000:
				GameData.SaveRoom (1);
				break;
			case 100000:
				GameData.SaveRoom (2);
				break;
			case 200000:
				GameData.SaveRoom (3);
				break;
			case 500000:
				GameData.SaveRoom (4);
				break;
			}
		}
		else
		{
			notEnoughCoinPannel.SetActive (true);
			Debug.Log ("Not Enough Money");
		}
	}

	#endregion

	#region Corutines

	IEnumerator StartLoading()
	{
		while(true)
		{
			loadingFilBar.fillAmount += 0.25f * Time.deltaTime;
			float amount = loadingFilBar.fillAmount * 100;
			loadingPercentageTxt.text = amount.ToString("00") + "%";
			if(loadingFilBar.fillAmount >= 1)
			{
				SceneManager.LoadSceneAsync ("playarea");
				StopCoroutine ("StartCoroutine");
				yield return 0;
			}
			yield return new WaitForSeconds (0.01f);
		}
	}

	#endregion
}
